@@ -1,6 +1,11 @@
 import pytest
-import boto3.session
-import botocore.client
+from boto3 import (
+    session
+)
+from botocore import (
+    exceptions,
+    client
+)
 from aviv_aws_costexplorer import base
 
 
@@ -12,11 +17,15 @@ def aacli():
 def test_awsclient(aacli):
     assert isinstance(aacli, base.AWSClient)
 
-    assert isinstance(aacli.sts, botocore.client.BaseClient)
-    assert isinstance(aacli.account_id, str)
-
-    assert isinstance(aacli.client('ce'), botocore.client.BaseClient)
-    assert isinstance(aacli.session(), boto3.session.Session)
+    assert isinstance(aacli.sts, client.BaseClient)
+    aid = None
+    with pytest.raises(exceptions.NoCredentialsError):
+        aid = aacli.account_id()
+    if not aid:
+        return
+    assert isinstance(aid, str)
+    assert isinstance(aacli.client('ce'), client.BaseClient)
+    assert isinstance(aacli.session(), session.Session)
 
 
 def test_sts_credentials(aacli):
